@@ -1,11 +1,14 @@
 from collections import defaultdict
 from copy import deepcopy
 from itertools import chain
-from typing import Callable, Dict, FrozenSet, Generic, Iterable, Iterator, List, Optional, Type, TypeVar, Union
+from operator import attrgetter
+from typing import Callable, Dict, FrozenSet, Generic, Iterable, Iterator, List, Optional, Tuple, Type, TypeVar, Union
 
 from tdm.abstract.datamodel import AbstractDirective, AbstractFact, AbstractTalismanDocument, AbstractTreeDocumentContent, FactType
 from tdm.abstract.datamodel.document import DocumentMetadata
 from tdm.datamodel.fact import ConceptFact, PropertyFact, RelationFact, ValueFact
+from . import CreateConceptDirective
+from .directive import CreateAccountDirective, CreatePlatformDirective
 from .fact import PropertyLinkValue
 
 _TalismanDocument = TypeVar('_TalismanDocument', bound='TalismanDocument')
@@ -166,8 +169,25 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                 yield directive
 
     def with_directives(self: _TalismanDocument, directives: Iterable[AbstractDirective]) -> _TalismanDocument:
+
+        all_directives = tuple(chain(self._directives, directives))
+        ret_directives = list(filter(lambda d: isinstance(d, (CreatePlatformDirective, CreateAccountDirective)), all_directives))
+
+        unique2directives = defaultdict(list)
+        for directive in filter(lambda d: isinstance(d, CreateConceptDirective), all_directives):
+            directive: CreateConceptDirective
+            unique2directives[directive.without_id()].append(directive)
+
+        ret_facts = []
+        for _, directives in unique2directives.items():
+            directive = directives[0]
+            ids = set(map(attrgetter('id'), directives[1:]))
+            ret_directives.append(directive)
+            for fact in self.filter_facts(ConceptFact, lambda f: f.value in ids):
+                ret_facts.append(fact.with_changes(value=directive.id))
+
         return type(self)(doc_id=self._doc_id, content=self._content, metadata=self._metadata, facts=self._facts,
-                          directives=tuple(directives))
+                          directives=tuple(ret_directives)).with_facts(ret_facts)
 
     def without_directives(self: _TalismanDocument) -> _TalismanDocument:
         return type(self)(doc_id=self._doc_id, content=self._content, metadata=self._metadata, facts=self._facts, directives=None)
@@ -204,3 +224,12 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                 continue
             if fact_.value.from_fact == fact and filter_(fact_.value.to_fact):
                 yield fact_.value.to_fact
+
+    def fact_text_mention(self, fact: AbstractFact) -> Optional[Tuple[str, ...]]:
+        if fact not in self._facts:
+            raise ValueError()
+        if fact.metadata and 'text' in fact.metadata:
+            return fact.metadata['text']
+        if fact.mention:
+            return tuple(map(self.content.text_for, fact.mention))
+        return None
