@@ -10,6 +10,7 @@ class NodeMetadata(BaseModel):
     node_type: NodeType
     original_text: Optional[str]
     text_translations: Dict[str, str] = {}
+    language: Optional[str] = None
     hidden: bool = False
 
     class Config:
@@ -24,5 +25,6 @@ class NodeMetadata(BaseModel):
             node_type=node.type,
             original_text=node.original_node_text if node.original_node_text != node.node_text else None,
             text_translations={lang: node.get_node_text_translation(lang) for lang in node.node_text_languages},
-            hidden=node.is_hidden
+            hidden=node.is_hidden,
+            language=node.language
         )
