@@ -6,15 +6,43 @@ from pydantic import BaseModel
 from tdm.abstract.datamodel import AbstractFact, AbstractTalismanDocument, FactType
 from tdm.datamodel import TalismanDocument
 from .content import TreeDocumentContentModel
-from .directive import CreateAccountDirectiveModel, CreateConceptDirectiveModel, CreatePlatformDirectiveModel
-from .directive.factory import build_directive_model
+from .directive import CreateAccountDirectiveModel, CreateConceptDirectiveModel, CreatePlatformDirectiveModel, build_directive_model
 from .fact import ConceptFactModel, PropertyFactModel, RelationFactModel, ValueFactModel, build_fact_model
-from .metadata import DocumentMetadataModel
+from ..abstract.json_schema import MetadataModel
 
 FactModel = Union[ConceptFactModel, ValueFactModel, PropertyFactModel, RelationFactModel]
 DirectiveModel = Union[CreateAccountDirectiveModel, CreateConceptDirectiveModel, CreatePlatformDirectiveModel]
 
 
+class DocumentMetadataModel(MetadataModel):
+    title: Optional[str]
+    file_name: Optional[str]
+    file_type: Optional[str]
+    size: Optional[int]
+    created_time: Optional[int]
+    access_time: Optional[int]
+    modified_time: Optional[int]
+    publication_date: Optional[int]
+    publication_author: Optional[str]
+    description: Optional[str]
+    language: Optional[str]
+    parent_uuid: Optional[str]
+    url: Optional[str]
+    platform: Optional[str]
+    account: Optional[Tuple[str, ...]]
+    access_level: Optional[str]
+    user: Optional[str]
+    path: Optional[str]
+    trust_level: Optional[float]
+    markers: Optional[Tuple[str, ...]]
+    related_concept_id: Optional[str]
+    preview_text: Optional[str]
+    story: Optional[str]
+
+    class Config:
+        extra = 'allow'  # any other extra fields will be kept
+
+
 class TalismanDocumentModel(BaseModel):
     id: str
     content: TreeDocumentContentModel
