@@ -1,10 +1,10 @@
-from typing import Any, Callable, Dict, Tuple
+from typing import Any, Dict
 
 from typing_extensions import Literal
 
-from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetadata, FactStatus, FactType
+from tdm.abstract.datamodel import AbstractFact, FactType
 from tdm.datamodel.fact import ValueFact
-from tdm.json_schema.fact.common import AbstractFactModel
+from tdm.json_schema.fact.common import AbstractFactModel, FactFactory
 
 
 class ValueFactModel(AbstractFactModel):
@@ -14,8 +14,7 @@ class ValueFactModel(AbstractFactModel):
         return self.value
 
     @property
-    def fact_factory(self) -> Callable[[str, FactStatus, str, Any, Tuple[AbstractTalismanSpan, ...], FactMetadata],
-                                       AbstractFact]:
+    def fact_factory(self) -> FactFactory:
         return ValueFact
 
     @classmethod
